diff libpurple/protocols/bonjour/jabber.c @ 29960:815bd8b41638

I before E, except after C
author Stu Tomlinson <stu@nosnilmot.com>
date Mon, 17 May 2010 01:01:13 +0000
parents 55913ed2a229
children 7c871249318b
line wrap: on
line diff
--- a/libpurple/protocols/bonjour/jabber.c	Mon May 17 00:18:25 2010 +0000
+++ b/libpurple/protocols/bonjour/jabber.c	Mon May 17 01:01:13 2010 +0000
@@ -386,7 +386,7 @@
 	BonjourBuddy *bb = NULL;
 	const gchar *name = bconv->pb ? purple_buddy_get_name(bconv->pb) : "(unknown)";
 
-	purple_debug_info("bonjour", "Recieved conversation close notification from %s.\n", name);
+	purple_debug_info("bonjour", "Received conversation close notification from %s.\n", name);
 
 	if(bconv->pb != NULL)
 		bb = purple_buddy_get_protocol_data(bconv->pb);
@@ -582,7 +582,7 @@
 }
 
 /* This gets called when we've successfully sent our <stream:stream />
  * AND when we've recieved a <stream:stream /> */
 void bonjour_jabber_stream_started(BonjourJabberConversation *bconv) {
 
 	if (bconv->sent_stream_start == NOT_SENT && !bonjour_jabber_send_stream_init(bconv, bconv->socket)) {
@@ -582,7 +582,7 @@
 
 /* This gets called when we've successfully sent our <stream:stream />
- * AND when we've recieved a <stream:stream /> */
+ * AND when we've received a <stream:stream /> */
 void bonjour_jabber_stream_started(BonjourJabberConversation *bconv) {
 